/*
 * No Agenda Show for Samsung SMARTHub 2011-2013
 * 
 * (c)	Copyright 2013 Brian Cadge / selectiveblur software
 * 		feedback@selectiveblur.co.uk
 */

alert('SceneLoading.js loaded');

function SceneLoading() {

};

SceneLoading.prototype.initialize = function () {
	alert("SceneLoading.initialize()");
	// this function will be called only once when the scene manager show this scene first time
	// initialize the scene controls and styles, and initialize your variables here
	// scene HTML and CSS will be loaded before this function is called
	$('#imgLoading').sfImage({src:'images/bgLoading.png'});
	$('#imgPreload').sfImage({src:'images/preload.gif'});
};

SceneLoading.prototype.handleShow = function (data) {
	alert("SceneLoading.handleShow()");
	// this function will be called when the scene manager show this scene
	// Wait for 2 seconds and then start loading the feeds.
	setTimeout(loadServerData,1500);	
};

SceneLoading.prototype.handleHide = function () {
	alert("SceneLoading.handleHide()");
	// this function will be called when the scene manager hide this scene
};

SceneLoading.prototype.handleFocus = function () {
	alert("SceneLoading.handleFocus()");
	// this function will be called when the scene manager focus this scene
};

SceneLoading.prototype.handleBlur = function () {
	alert("SceneLoading.handleBlur()");
	// this function will be called when the scene manager move focus to another scene from this scene
};

SceneLoading.prototype.handleKeyDown = function (keyCode) {
	alert("SceneLoading.handleKeyDown(" + keyCode + ")");
	// TODO : write an key event handler when this scene get focued
	switch (keyCode) {
		case sf.key.LEFT:
			break;
		case sf.key.RIGHT:
			break;
		case sf.key.UP:
			break;
		case sf.key.DOWN:
			break;
		case sf.key.ENTER:
			break;
		default:
			alert("handle default key event, key code(" + keyCode + ")");
			break;
	}
};

function loadServerData()
{
	var returncode;
	
	 if (Server.init())
	    {
		    alert("------ Server did init");
		    try
		    {
			    // Store which generation of product this is.
			    Data.TVmodelyear = sf.env.getFirmwareVer().year;
		    }
		    catch(e)
		    {
		    	Data.TVmodelyear = '2013';
		    }
		    returncode = false;

		    if (Server.checkConnection())
		    	{
			    // Get the bootstrap config from the selectiveblur calendar
		    	returncode = Server.fetchBootConfig();
			    alert("------- fetchBootConfig returned "+returncode);
			    alert("@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ "+Server.showsurl);
			    alert("@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ "+Server.liveurl);
			    alert("@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ "+Data.aboutURL);
			    alert("@@@@@@@@@@@@@@@@@@@@@@@@@@@@@ "+Server.calurl);
		    	}
		    
		    setTimeout(loadEpisodes,1300);
	    }
	    else
	    {
	       criticalStartupError("Sorry, the connection to the server failed to initialise. Please try again later.<br><br>The application cannot continue and will now close.");
	    }	
}


function loadEpisodes()
{
	var returncode;
	
    if (Server.checkConnection())
		{
		// Get the list of available feeds (shows) from the server
		returncode = Server.fetchEpisodeList(Server.showsurl);

		if ((returncode) && (Server.checkConnection()))
			{
			setTimeout(loadArtwork,300);
			}
		else
			{
			criticalStartupError("Sorry, the connection to the No Agenda Show server could not be established. Please check your Internet connection and try again.<br><br>The application cannot continue and will now close.");
			}
		}
    else
    	{
    	criticalStartupError("The network is disconnected. Please check your Internet connection and try again.<br><br>The application cannot continue and will now close.");
    	}
}


function loadArtwork()
{
	if (Server.checkConnection())
		{
		// Try to pre-cache all the artwork files...
	    for (var index = 0; index < (Data.getEpisodeCount()); index++)
	    	{
	    	var imagePreloading = new Image();
	    	imagePreloading.src = Data.getArtworkURL(index);
	    	}		        	
	    setTimeout(loadCalendar,300);
		}
    else
		{
		criticalStartupError("The network is disconnected. Please check your Internet connection and try again.<br><br>The application cannot continue and will now close.");
		}
}


function loadCalendar()
{
	if (Server.checkConnection())
		{
	    // Pre-load the radio calendar feed for now/next information
	    Server.fetchNowNextInfo();
		
	    // Check the date is set on the TV (buggy on some models if Internet not connected at power-up)
		var timecheck = Data.getCurrentDateTime();
		if (timecheck.getFullYear() < 2013)
			{
			$('#PopUp').sfPopup({
				'text': 'The date is not set correctly on your device ('+dateFormat(timecheck,"dd mmm yyyy")+'). Guide listings will not be available for Live broadcasts.<br><br>Check your Internet connection is working. You may need to power cycle your device to fix the problem.',
				buttons:['OK'],
				timeout: 45000,
				callback:function(rlt){
					// Carry on
					setTimeout(doneLoading,200);
				}
			});
			$('#imgPreload').sfImage({src:'images/preloadblank.gif'});
			$('#PopUp').sfPopup('show');					
			}
		else
			{
			setTimeout(doneLoading,500);
			}
		}
	else
		{
		criticalStartupError("The network is disconnected. Please check your Internet connection and try again.<br><br>The application cannot continue and will now close.");
		}	
}


function doneLoading()
{
	// Data done loading from server.  Load the local config
	// Data.LoadLocalConfig();
	// Initialise the user PlayList history
	// Data.initUserPlayList();
	// Load the user Playlist history
	// Data.loadUserPlayList();

	if (Server.checkConnection())  //Defect DF-130726-88118 - Ensure network cable message is displayed even at end of loading...
		{
	    // Switch to the main showlist scene
		$('#imgPreload').sfImage({src:'images/preloadblank.gif'});
		sf.scene.show('ShowSelect');
		sf.scene.hide('loading');
		sf.scene.focus('ShowSelect');
		}
	else
		{
		criticalStartupError("The network is disconnected. Please check your Internet connection and try again.<br><br>The application cannot continue and will now close.");
		}	
}

function criticalStartupError(textError)
{
	alert("********* "+textError);
	$('#imgPreload').sfImage({src:'images/preloadblank.gif'});
	$('#PopUp').sfPopup({
		'text': textError,
		buttons:['Exit Application'],
		timeout: 45000,
		callback:function(rlt){
			if (rlt==-1)
				{
				// Need to check which key was pressed for correct behaviour when pressing RETURN/EXIT (Defect DF-130314-65768)
				var key=0;
				try
				{
					if (typeof event != undefined)
					{
					key = event.keyCode;
					}					
				}
				catch(e)
				{
					// Couldn't get the keycode event?
					key=0;
				}
				if (key == sf.key.EXIT)
					{
					// EXIT key was pressed, so exit completely
					alert("EXIT KEY");
					sf.core.exit(true);
					}
				else
					{
					// RETURN key or timeout, so exit to Smarthub
					alert("NOT EXIT KEY");
					sf.core.exit(false);
					}
				}
			else
				{
				// ENTER key was pressed, so exit to SmartHub
				sf.core.exit(false);
				}
		}
	});
	$('#PopUp').sfPopup('show');
}
